<?php

/**
 * @file
 * Definition of Drupal\grid\Grid.
 */

namespace Drupal\grid;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\grid\Plugin\GridInterface;

/**
 * Defines the grid entity.
 */
class Grid extends ConfigEntityBase implements GridInterface {

  /**
   * The grid ID (machine name).
   *
   * @var string
   */
  public $id;

  /**
   * The grid UUID.
   *
   * @var string
   */
  public $uuid;

  /**
   * The grid label.
   *
   * @var string
   */
  public $label;

  /**
   * Plugin identifier for this grid.
   *
   * @var string
   */
  public $type;

  /**
   * Plugin configuration to instantiate the plugin instance.
   *
   * @var array
   */
  public $options;

  /**
   * Instantiated plugin to handle the grid.
   *
   * @see Drupal\grid\Grid::GetPlugin().
   *
   * @var Drupal\grid\Plugin\GridInterface
   */
  public $plugin;

  /**
   * Get a plugin instance for this grid.
   */
  public function getPlugin() {
    if (!isset($this->plugin)) {
      // Pass on Grid ID as part of the configuration array.
      $this->options['id'] = $this->id;
      $this->plugin = drupal_container()->get('plugin.manager.grid')->createInstance($this->type, $this->options);
    }
    return $this->plugin;
  }

  /**
   * Implements Drupal\grid\Plugin\GridInterface::getGridCss().
   */
  public function getGridCss($wrapper_selector = NULL, $col_selector_prefix = NULL, $skip_spacing = FALSE) {
    return $this->getPlugin()->getGridCss($wrapper_selector, $col_selector_prefix, $skip_spacing);
  }

}
