<?php

/**
 * @file
 * Definition of Drupal\page\PageFormController.
 */

namespace Drupal\page;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityFormController;

/**
 * Form controller for the page edit/add forms.
 */
class PageFormController extends EntityFormController {

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::form().
   */
  public function form(array $form, array &$form_state, EntityInterface $page) {
    $form['label'] = array(
      '#type' => 'textfield',
      '#title' => t('Label'),
      '#maxlength' => 255,
      '#default_value' => $page->label(),
      '#description' => t("Example: 'Front page' or 'Section page'."),
      '#required' => TRUE,
    );
    $form['id'] = array(
      '#type' => 'machine_name',
      '#default_value' => $page->id(),
      '#machine_name' => array(
        'exists' => 'page_load',
        'source' => array('label'),
      ),
      '#disabled' => !$page->isNew(),
    );

    // Get list of layouts and expose that for page layout selection.
    $layouts = drupal_container()->get('plugin.manager.layout')->getDefinitions();
    $layout_options = array();
    foreach ($layouts as $key => $layout) {
      $layout_options[$key] = $layout['title'];
    }
    $form['layout'] = array(
      '#type' => 'select',
      '#title' => t('Layout for this page'),
      '#default_value' => isset($page->layout) ? $page->layout : '',
      '#options' => $layout_options,
    );

    // @todo this would ideally be pluggable and depend on general conditions
    // and all, however, these are not yet abstracted.
    $options = array(
      0 => t('All paths except those listed'),
      1 => t('Only the listed paths'),
    );
    $description = t("Enter one path per line. The '*' character is a wildcard. Example paths are %user for the current user's page and %user-wildcard for every user page. %front is the front page.", array('%user' => 'user', '%user-wildcard' => 'user/*', '%front' => '<front>'));
    $form['visibility'] = array(
      '#type' => 'radios',
      '#title' => t('Apply to specific paths'),
      '#options' => $options,
      '#default_value' => isset($page->visibility) ? $page->visibility : 0,
    );
    $form['paths'] = array(
      '#type' => 'textarea',
      '#title' => '<span class="element-invisible">' . t('Paths') . '</span>',
      '#default_value' => isset($page->paths) ? $page->paths : '',
      '#description' => $description,
    );

    return parent::form($form, $form_state, $page);
  }

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::actions().
   */
  protected function actions(array $form, array &$form_state) {
    // Only includes a Save action for the entity, no direct Delete button.
    return array(
      'submit' => array(
        '#value' => t('Save'),
        '#validate' => array(
          array($this, 'validate'),
        ),
        '#submit' => array(
          array($this, 'submit'),
          array($this, 'save'),
        ),
      ),
    );
  }

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::save().
   */
  public function save(array $form, array &$form_state) {
    $page = $this->getEntity($form_state);
    $page->save();

    watchdog('page', 'Page @label saved.', array('@label' => $page->label()), WATCHDOG_NOTICE);
    drupal_set_message(t('Page %label saved.', array('%label' => $page->label())));

    $form_state['redirect'] = 'admin/structure/pages';
  }

}

