<?php

/**
 * @file
 * Definition of Drupal\page\PageListController.
 */

namespace Drupal\page;

use Drupal\Core\Config\Entity\ConfigEntityListController;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityStorageControllerInterface;

/**
 * Provides a listing of pages.
 */
class PageListController extends ConfigEntityListController {

  /**
   * Get form for listing page to display for weights.
   */
  public function getForm($form, &$form_state) {
    $form['items'] = array(
      '#tree' => TRUE,
    );
    foreach ($this->load() as $entity) {
      $form['items'][$entity->id()]['label'] = array(
        '#markup' => check_plain($entity->label()),
      );

      $paths = nl2br(check_plain($entity->paths));
      if (empty($entity->visibility)) {
        $paths = t('Except: !paths', array('!paths' => '<br />' . $paths));
      }
      $form['items'][$entity->id()]['paths'] = array(
        '#markup' => $paths,
      );

      $form['items'][$entity->id()]['weight'] = array(
        '#type' => 'weight',
        '#title' => t('Weight'),
        '#default_value' => $entity->weight,
        '#delta' => 100,
        '#attributes' => array('class' => array('entity-weight')),
      );

      $form['items'][$entity->id()]['operations'] = array(
        $this->buildOperations($entity),
      );
    }

    $form['actions'] = array();
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Save changes')
    );
    return $form;
  }

  /**
   * Save weight changes to configuration entities.
   */
  public function submitForm($form, &$form_state) {
    foreach ($form_state['values']['items'] as $id => $item) {
      $page = entity_load('page', $id);
      $page->weight = $item['weight'];
      $page->save();
    }
  }

}
