<?php

/**
 * @file
 * Administration functions to maintain a set of pages using layouts.
 */

use Drupal\page\Page;

/**
 * Page callback: Presents list of pages.
 *
 * @see page_menu()
 */
function page_page_list() {
  return drupal_get_form('page_page_list_form');
}

/**
 * Form callback to present a tabledrag list.
 */
function page_page_list_form($form, &$form_state) {
  $controller = entity_list_controller('page');
  return $controller->getForm($form, $form_state);
}


/**
 * Form callback to save a tabledrag list.
 */
function page_page_list_form_submit($form, &$form_state) {
  $controller = entity_list_controller('page');
  return $controller->submitForm($form, $form_state);
}

/**
 * Page callback: Presents the page editing form.
 *
 * @see page_menu()
 */
function page_page_edit(Page $page) {
  drupal_set_title(t('<em>Edit page</em> @label', array('@label' => $page->label())), PASS_THROUGH);
  return entity_get_form($page);
}

/**
 * Page callback: Provides the new page addition form.
 *
 * @see page_menu()
 */
function page_page_add() {
  $page = entity_create('page', array());
  return entity_get_form($page);
}

/**
 * Page callback: Form constructor for page deletion confirmation form.
 *
 * @see page_menu()
 */
function page_delete_confirm($form, &$form_state, Page $page) {
  // Always provide entity id in the same form key as in the entity edit form.
  $form['id'] = array('#type' => 'value', '#value' => $page->id());
  $form_state['page'] = $page;
  return confirm_form($form,
    t('Are you sure you want to remove the page %title?', array('%title' => $page->label())),
    'admin/structure/pages',
    t('This action cannot be undone.'),
    t('Delete'),
    t('Cancel')
  );
}

/**
 * Form submission handler for page_delete_confirm().
 */
function page_delete_confirm_submit($form, &$form_state) {
  $page = $form_state['page'];
  $page->delete();
  drupal_set_message(t('Page %label has been deleted.', array('%label' => $page->label())));
  watchdog('page', 'Page %label has been deleted.', array('%label' => $page->label()), WATCHDOG_NOTICE);
  $form_state['redirect'] = 'admin/structure/pages';
}

/**
 * Theme callback for page listing form.
 */
function theme_page_page_list_form($variables) {
  $form = $variables['form'];
  $rows = array();

  foreach (element_children($form['items'], TRUE) as $id) {
    $rows[] = array(
      'data' => array(
        drupal_render($form['items'][$id]['label']),
        drupal_render($form['items'][$id]['paths']),
        drupal_render($form['items'][$id]['weight']),
        drupal_render($form['items'][$id]['operations']),
      ),
      'class' => array('draggable'),
    );
  }

  $header = array(
    t('Label'),
    t('Paths'),
    t('Weight'),
    t('Operations'),
  );

  $variables = array(
    'header' => $header,
    'rows' => $rows,
    'attributes' => array('id' => 'page-list'),
  );
  $table  = theme('table', $variables);
  $table .= drupal_render_children($form);
  drupal_add_tabledrag('page-list', 'order', 'sibling', 'entity-weight');
  return $table;
}
